.. celltypist documentation master file, created by
   sphinx-quickstart on Thu Mar  4 16:45:59 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to celltypist's documentation!
======================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   celltypist


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
